FilterGroups

Struct FilterGroups 

pub struct FilterGroups(/* private fields */);
A FilterGroups is a vector of FilterGroup, and each groups are intended to be OR between them, and inside the group, that will be the And

Implementations

Source

impl FilterGroups

pub fn add_group(&mut self, group: Vec<FilterNode>) -> &mut Self

Add a new or group (Vec<FilterNode>). It will be OR with its peer groups, and the content of the vector should interpreted as AND.

pub fn groups(&self) -> &Vec<FilterGroup>

pub fn into_vec(self) -> Vec<FilterGroup>